/**
 * komponente Cooky ->
 * basiskomponente zum bearbeiten von cookies
 */
function Cooky() {
	function createDeleteDate() {
		var delDate = new Date();
		delDate.setTime(Date.UTC(1970, 0, 1, 00, 00, 00));
		return delDate;
	}
	/**
	 *   pr�ft ob cookies �berhaupt erlaubt sind
	 */
	this.cookiesEnabled = function() {
		var date = new Date();
		date.setMinutes(date.getMinutes() + 100000);
		document.cookie = "tstCheckCookie=test; expires=" + date.toUTCString();
		var cookies = document.cookie;
		if (cookies.indexOf("tstCheckCookie=test") == -1) {
			return false;
		} else {
			document.cookie = "tstCheckCookie=test; expires="
					+ createDeleteDate();
			return true;
		}
	};
	/**
	 * pr�ft ob cooky vorhanden ist
	 * @param {string} name Cooky name
	 * 
	 */
	this.cookyExists = function(name) {
		return document.cookie.indexOf(name) > -1;
	};

	/**
	 * erzeugt cookie
	 * @param {string} name Cooky name
	 * @param {string} value Cooky Wert
	 * @param {date} date Cooky verfallsdatum
	 * @param {string} domain Cooky domain
	 * @param {string} path Cooky pfad
	 * @param {string} secure Cooky 
	 */
	this.createCooky = function(name, value, expires, domain, path, secure) {

		var cookie = name + "=";
		(value) ? cookie += encodeURIComponent(value) : cookie += "";
		(expires) ? cookie += "; expires=" + expires.toGMTString() : "";
		(domain) ? cookie += "; domain=" + domain : "";
		(path) ? cookie += "; path=" + path : "";
		(secure) ? cookie += "; secure=" + secure : "";
		document.cookie = cookie + ";";
	};

	/**
	 * liest cooky wert
	 * @param {string} name Cooky name
	 */
	this.readCooky = function(name) {
		var retval;
		var allCookies = document.cookie;
		if (this.cookyExists(name)) {
			var regex = new RegExp('(?:^|;)\\s?' + name + '=(.*?)(?:;|$)', 'i');
			var match = allCookies.match(regex);
			retval = match && unescape(match[1]);
		}
		return retval;
	};

	/**
	 * l�scht cooky anhand seines namens, domain, pfad
	 * @param {string} name Cooky name
	 * @param {string} domain Cooky domain
	 * @param {string} path Cooky pfad
	 */
	this.deleteCooky = function(name, domain, path) {
		if (this.cookyExists(name)) {
			this.createCooky(name, "", createDeleteDate(), domain, path);
		}
		;
	};
}

/**
 * komponente zum rendern der cooky notification
 * -> wenn cookies ausgeschalten
 */
function CookyNotification(configuration) {
	var config = configuration;
	/**
	* renders cookie notification
	* notification will be shown when cookies are not allowed
	*/
	this.render = function() {
		if (config.cookieNotificationHtml) {
			if (jQuery("#cookieNotification").length == 0) {
				jQuery(config.cookieNotificationHtml).appendTo("body");
			}
			jQuery("#cookieNotification").show();
		} else {
			if(typeof console !== "undefined" && console) {
				console.log("No notification Html configured:", config);
			}
		}
	};
	
	/**
	* register events for cookie notification
	*/
	this.registerEvents = function() {
	};
}

/**
 * komponente zum rendern der cooky information
 * -> wenn cookies erlaubt, aber cl-cookie noch nicht gesetzt
 */
function CookyInformation(configuration) {
	var config = configuration;
	var cooky = new Cooky();

	var getMaxCat = function() {
		var catNum = -1;
		for ( var k in config.cookyCategories) {
			var keyVal = parseInt(k);
			if (keyVal > catNum) {
				catNum = keyVal;
			}
		}
		return catNum;
	};

	var synchronizeButtonWidth = function(){
	  var setButtonWidth = jQuery("#coset span").width();
	  var notSetButtonWidth = jQuery("#conoset span").width();
	  if(setButtonWidth > notSetButtonWidth){
	    jQuery("#conoset span").width(setButtonWidth);
	    jQuery("#conoset span").css("text-align","center");
	  } else if (setButtonWidth < notSetButtonWidth){
	    jQuery("#coset span").width(notSetButtonWidth);
	    jQuery("#coset span").css("text-align","center");
	  }
	};
	/**
	* renders cookie information if 'cookie law cookie' is not set
	*/
	this.render = function() {
		if (config.cookieInformationHtml) {
			if (jQuery("#cookieInformation").length == 0) {
				var infElem = jQuery(config.cookieInformationHtml);
				infElem.find("a.coset").attr("data-toggle", "modal").attr("data-target", "#modal-scene-cookie");
				infElem.appendTo("body");
			}
			synchronizeButtonWidth();
			jQuery("#cookieInformation").show();
		} else {
			if(typeof console !== "undefined" && console) {
				console.log("No information Html configured:", config);
			}
		}
	};
	/**
	* register events for cookie information
	*/
	this.registerEvents = function() {

		jQuery("#cookieInformation").delegate(
				"#conoset",
				"click",
				function(event) {
					event.preventDefault();
					cooky.createCooky(config.clName, getMaxCat(),
							config.expireDate, "", "/"); 
					jQuery(window).trigger("cookieSaved" , [ getMaxCat(),function(){window.location.reload();} ]);
					
				});

		jQuery("#cookieInformation").delegate("#coset", "click",
				function(event) {
					event.preventDefault();
					jQuery("#cookieInformation").hide();
				});

		// wenn lightbox vorhanden dann init
		if (window.initBlb && typeof window.initBlb == "function") {
			window.initBlb();
		}
	};
}

/**
 * komponenten zum bearbeiten der Iconbar
 */
function IconBar(configuration) {
	var config = configuration;
	/**
	 * aktualisiert iconbar
	 * ben�tigt elemente mit der css-klasse "js-footer-cooky"
	 * je nach cooky kategorie wird an das element und seine
	 *  kind elemente die css-klasse "active" gebunden 
	 */
	var cooky = new Cooky();
	this.updateTexts = function(){
		var headText = "";
		if(config.labels && config.labels.popupheader){
			headText  = config.labels.popupheader;
		};
		if(headText.length > 0){
			var elems = jQuery(".js-footer-cookie > a");
			elems.each(function(index) {
				jQuery(this).attr("title", headText).attr("inlhead", headText).attr("data-toggle", "modal").attr("data-target","#modal-scene-cookie");
				
			});
		}
	};
	this.update = function() {
		var cat = parseInt(cooky.readCooky(config.clName));
		var elems = jQuery(".js-footer-cookie");
		
		elems.each(function(index) {
			// title resetten
			jQuery(this).attr("title", "");
			jQuery(this).children().attr("title", "");

			// active status resetten
			jQuery(this).removeClass("active");
			jQuery(this).children().removeClass("active");

			// 	title attribute hinzuf�gen
			jQuery(this).attr("title",
					config.cookyCategories[index].description);
			jQuery(this).children().attr("title",
					config.cookyCategories[index].description);
			if (index == cat) {
				jQuery(this).addClass("active");
				jQuery(this).children().addClass("active");
			}
		});
	};

	this.registerEvents = function() {

	};
}

/**
 * Versucht die Url der Konfigurationsdatei(cl.json)
 * aufzul�sen
 * 
 * @constructor
 */
function DefaultConfigUrlResolverStrategy(urlPartPrefix) {
	var urlPartPref = "" || urlPartPrefix;
	var configFileName = "cl.json";
	var pathPart = "/technical-pages/cookielaw/";
	var pathParts = {
			"localhost:8080":"/technical-pages/cookielaw/",
			"www.bosch-professional.com":"/technical-pages/cookielaw/",
			"www.bosch-professional.com_ssl":"/technical-pages/ssl/cookielaw/",
			"www.skilmasters.com":"/technical-pages/cookielaw/",
			"www.skileurope.com":"/technical-pages/cookielaw/",
			"www.bosch-pt.com":"/ac/technical-pages-professional/cookielaw/",
			"diamondSpecial":"/ac/technical-pages-professional/cookielaw_diamond/",
			"cstberger.kittelberger.net":"/technical-pages/cookielaw/",
			"obelix":"/technical-pages/cookielaw/",
			"www.bosch-plr15.com":"/technical-pages/cookielaw/",
			"bosch-plr15.com":"/technical-pages/cookielaw/",
			"bosch-plr50c.com":"/technical-pages/cookielaw/",
			"www.bosch-plr50c.com":"/technical-pages/cookielaw/"
	};
	var resolveCommunityDomain = function(){
		var domainCLs = {'www.bosch-pt.ru':'/ru/ru/','www.bosch-pt.de':'/de/de/'};
		var hostName = window.location.host.toLowerCase();
		var cl = "";
		var retval = "";
		if(	domainCLs[ hostName ]){
			cl = domainCLs[ hostName ];
		}
		if(cl != ""){ 
			retval = window.location.protocol + "//www.bosch-professional.com" + cl + pathPart + configFileName;
		}
		
		
		return "";
	};
	
	var resolveWebtrendsMeta = function(){
		var retval = "";
		var lang = "";
		var country = "";
		
		lang = jQuery("meta[name='DCSext.wtg_lang']").attr("content");
		country = jQuery("meta[name='DCSext.wtg_country']").attr("content");
		
		if( (country && country != "") && (lang && lang != "") ){
			retval = window.location.protocol + "//" + window.location.host;
			retval += "/" + urlPartPref.replace(/^\//, "").replace(/\/$/, "")+ "/" + country.toLowerCase() + "/" + lang.toLowerCase() + pathParts[ window.location.host.toLowerCase() ] + configFileName;
		}
		return retval;
	}
	
	var isDiamondSpecial = function(){
		var diamondRegex = /\/diamond[\/]?/i;
		return diamondRegex.test(window.location.pathname);
	};
	
	var getPathPartsKey = function(){
		if (isDiamondSpecial()) {
			return "diamondSpecial";
		} else if (window.location.protocol === 'https:') {
			return window.location.host.toLowerCase() + "_ssl";
		} else {
			return window.location.host.toLowerCase();
		}
	};
	
	/**
	 * l�st konfigurationsurl auf
	 * hier wird von folgender konvention ausgegangen
	 * <schema>://<host>:<port>/<prefix>/<land>/<sprache>/technical-pages/cookielaw/cl.json
	 * in entwicklungsprojekten(wie ocs) kann das auch <land>-<sprache>-ocs sein, das soll hier ber�cksichtigt
	 * werden 
	 */
	this.resolveConfigUrl = function() {
		var prdRegex = new RegExp("/(mea|general|master|[a-z]{2,2})/([a-z]{2,2})/", "i");
		var devRegex = new RegExp(
				"/(master|[a-z]{2,2})-([a-z]{2,2})-([a-z0-9]+)/", "i");
		var matches = [];
		var retval = "";

		if (prdRegex.test(window.location.pathname)) {
			matches = prdRegex.exec(window.location.pathname);
		} else if (devRegex.test(window.location.pathname)) {
			matches = devRegex.exec(window.location.pathname);
		}
		if (matches.length >= 2) {
			if( window.location.host!="www.bosch-plr15.com" && window.location.host !="obelix" && window.location.host!="bosch-plr15.com" && window.location.host!="www.bosch-plr50c.com" && window.location.host!="bosch-plr50c.com") {
                retval = window.location.protocol + "//" + window.location.host;    
            } else {
                retval = "http://www.bosch-professional.com";
            }
			retval += urlPartPref.replace(/^\//, "").replace(/\/$/, "")
					+ "/" + matches[1] + "/" + matches[2];
			retval += pathParts[ getPathPartsKey() ] + configFileName;
		}
		
		console.log(getPathPartsKey())
		// die Sprachauflösung hat nicht funktioniert
		// prüfen ob country/lang parameter existieren
		if(!retval || retval == "" ){
			var countryMatches = window.location.search.match(/(country)=(MASTER|GENERAL|[a-zA-Z]{2,2})/,"i");
			var langMatches = window.location.search.match(/(lang)=(MASTER|GENERAL|[a-zA-Z]{2,2})/,"i");
			if(countryMatches && countryMatches.length == 3 && langMatches && langMatches.length == 3){
				retval = window.location.protocol + "//" + window.location.host;
				retval += "/" + urlPartPref.replace(/^\//, "").replace(/\/$/, "")
						+ "/" + countryMatches[2].toLowerCase() + "/" + langMatches[2].toLowerCase();
				retval += pathParts[ getPathPartsKey() ] + configFileName;
			}
		}
		
		if(!retval || retval == "" ){
			retval = resolveCommunityDomain();
		}
		
		// letzte möglichkeit -> webtrends meta
		if(!retval || retval == "" ){
			retval = resolveWebtrendsMeta();
		}
		console.log(retval);
		return retval;
		// return "http://www.bosch-professional.com/de/de/technical-pages/cookielaw/cl.json?callback=jsonpCallback&_=1415957445637";
	};
}

/**
 * cookymanager komponente
 */
function CookyManager(configuration) {
	var config = configuration;
	var cooky = new Cooky();
	var allowedElem = null;
	var disallowedElem = null;
	var sliderElem = null;
	var aktCookyCat = cooky.readCooky(config.clName);
	

	
	var useDoNotTrack = function(){
		var retval = false;
		if(typeof config.doNotTrack !== "undefined" && (config.doNotTrack=="true") ){
			retval = true;
		}
		return retval;
	};
	
	var determineNotConfiguredCookieCat = function(){
		var retval = 1;
		var dnt = "";
		if(useDoNotTrack() ){
			if(navigator.doNotTrack){
				dnt = "" + navigator.doNotTrack + "".toLowerCase();
								 
			} else if (navigator.msDoNotTrack){
				dnt = "" + navigator.msDoNotTrack + "".toLowerCase();
			}
			
			if(typeof console !== "undefined" && console){
				console.log("CookyManager determineNotConfiguredCookieCat dnt: " + dnt);
			};
		}
		
		if(dnt == "1" || dnt == "yes"){
			retval = 0;
		};
		return retval;
	};
	if(typeof console !== "undefined" && console){
		console.log("CookyManager aktCookyCat start:" + aktCookyCat);
	}
	if (!aktCookyCat) {
		aktCookyCat = determineNotConfiguredCookieCat();
	}
	if(typeof console !== "undefined" && console){
		console.log("CookyManager aktCookyCat: " + aktCookyCat);
		
	}
	if($.nmFilters){
		$.nmFilters({"clFilter": new CookieLawNyroModalFilter() });
	};
	this.registerEvents = function() {
		if(typeof console !== "undefined" && console){
			console.log("CookyManager.registerEvents");
		}
		
		// click events auf slider
		jQuery("#cmContentArea").delegate(
				"div.cmM-cookieslider ul li",
				"click",
				function(event) {
					var sliElem = jQuery(this);
					jQuery.each(config.cookyCategories,
							function(catLevel, cat) {
								if (sliElem.hasClass("cmM-cookieslider-"
										+ catLevel)) {
									aktCookyCat = catLevel;
									return false;
								}
							});
				//	renderAllowedCookies();
				//	renderDisallowedCookies();
					renderCookySlider();
				});
		// fenster schlie�en, ohne zu speichern
		jQuery("#cmContentArea").delegate("a.js-link-cancel", "click",
				function(event) {
					event.preventDefault();
					// jQuery("a.nyroModalClose").trigger("click");
					jQuery("#modal-scene-cookie").modal('hide');
					return false;
				});

		// speichern und schlie�en
		jQuery("#cmContentArea").delegate(
				"a.js-link-save",
				"click",
				function(event) {
					event.preventDefault();
					// cookywert auf alle f�lle schreiben
					cooky.createCooky(config.clName, aktCookyCat,
							config.expireDate, "", "/");
					// nicht ben�tigte cookies entfernen
					removeUnusedCookies();
					// seit neu ladeng
					jQuery(window).trigger("cookieSaved" , [ aktCookyCat,function(){window.location.reload();} ]);
					return false;
				});

		jQuery("#cmContentArea").delegate("a[href='#m-bottom']", "click",
				function(event) {
					event.preventDefault();
					jQuery('.nyroModalCont').animate({
						scrollTop : jQuery("#headline").offset().top
					}, 1000);
				});

		jQuery("body").delegate("a[href='#m-top']", "click", function(event) {
			event.preventDefault();
			jQuery('.nyroModalCont').animate({
				scrollTop : jQuery("body").offset().top
			}, 1000);

		});
		// cookie informationen anzeigen
		jQuery("#cmContentArea").delegate("a#showUsedCookies", "click", function(event){
			event.preventDefault();
			jQuery(".cmTable").toggle(0,function(){
				var descTables = jQuery(".cmTable:visible");
				if(descTables.length == 0){
					jQuery("div.nyroModalCont").width("744px");
				} else {
					jQuery("div.nyroModalCont").width("754px");
				}
			});
			return false;
		});
	};

	var removeUnusedCookies = function() {
		jQuery.each(config.cookies, function(index, catCookies) {
			var ind = parseInt(index);
			if (ind > aktCookyCat) {
				for (var i = 0; i < catCookies.length; i++) {
					cooky.deleteCooky(catCookies[i], "", "/");
				}
			}
		});
	};

	var renderAllowedCookies = function() {
		var cookyLevel = 1;

		var allowedList = jQuery("#cmContentArea ul.cmM-list-e-benefit");

		allowedList.empty();
		for (var i = 1; i <= cookyLevel; i++) {
		  
			var cookies = config.cookies[i+""];
			var numc = cookies.length;

			for (var j = 0; j < numc; j++) {
				var alCooky = cookies[j];
				var insElement = jQuery("<li><p></p></li>");
				insElement.addClass("level" + i);
				insElement.children("p").empty().html(alCooky.description);
				allowedList.append(insElement);
			}
		}
	};

	var renderDisallowedCookies = function() {
		var cookyLevel = 0;
		// parseInt(aktCookyCat);
		var allowedList = jQuery("#cmContentArea ul.cmM-list-e-disadvantage");

		allowedList.empty();
		jQuery.each(config.cookyCategories, function(catLevel, cat) {
			var levelNum = parseInt(catLevel);
			if (levelNum <= cookyLevel) {
				var alCookies = config.cookies[""+levelNum];
				jQuery.each(alCookies, function(index, alCookyVal) {
					var insElement = jQuery("<li><p></p></li>");
					insElement.addClass("level" + catLevel);
					insElement.children("p").empty().html(alCookyVal.description);
					allowedList.append(insElement);
				});

			}
		});
	};

	var renderCookySlider = function() {
		var cookyLevel = parseInt(aktCookyCat);
		var sliderList = jQuery("#cmContentArea div.cmM-cookieslider ul");
		var sliderElems = sliderList.children("li");

		sliderElems.each(function(index) {
			jQuery(this).removeClass("active");
			jQuery(this).addClass("cmM-cookieslider-" + index);
			if (index == cookyLevel) {
				jQuery(this).addClass("active");
			}
		});
		
	};

	var renderCookiesInformation = function() {
		var tableArea = jQuery("#cmCookyDescriptions");
		var tableDiv = tableArea.children("#cmTable").clone();
		tableArea.children("#cmTable").remove();
		jQuery.each(config.cookyCategories, function(catVal, category) {
			jQuery.each(config.cookies[catVal],
					function(cookyIndex, cookyVal) {
						var insTableDiv = tableDiv.clone();
						insTableDiv.attr("id", "table_" + catVal + "_"
								+ cookyIndex);
						insTableDiv.find(".cmCookyNameValue").html(
								cookyVal.name.replace(/\$\{clCookyName\}/gi,
										config.clName));
						insTableDiv.find(".cmCookyCatValue")
								.html(category.name);
						insTableDiv.find(".cmCookyTypeValue").html(
								cookyVal.type);
						insTableDiv.find(".cmCookyPurposeValue").html(
								cookyVal.purpose);
						insTableDiv.append('<div class="clear"></div>');
						tableArea.append(insTableDiv);
					});
		});
	};

	var renderInlineScript = function() {
		var cookyLevel = parseInt(aktCookyCat);
		for(var i=0;i<=cookyLevel;i++){
			if (config["inlineRendering"] && config["inlineRendering"][i]) {
				jQuery.each(config["inlineRendering"][i], function(index,
						inlineVal) {
					jQuery(inlineVal).appendTo("body");
				});
			}
		}
		jQuery(window).trigger("cookieLaw.renderInlineScriptReady",[cookyLevel],function(){
			if(typeof console !== "undefined" && console) {
				console.log("Event cookieLaw.renderInlineScriptReady triggered");
			}
		});
	};

	this.render = function() {
		var managerElem = jQuery(
				"<div class=\"modal fade\" id=\"modal-scene-cookie\" tabindex=\"-1\" role=\"dialog\" aria-hidden=\"true\"><div class=\"modal-dialog\"><div class=\"modal-content\"><div class=\"modal-header\"><button type=\"button\" class=\"close\" data-dismiss=\"modal\"><span aria-hidden=\"true\">×</span><span class=\"sr-only\">Close</span></button></div><div class=\"modal-body\">"+ config.managerHtml + "</div></div></div></div></div>");
		managerElem.find("a.js-link-cancel").addClass("close").attr("data-dismiss", "modal");
		
		managerElem.appendTo("body");		
		if(!config.headless){
			renderAllowedCookies();
			renderDisallowedCookies();
			renderCookySlider();
		}
		// renderCookiesInformation();
		renderInlineScript();
		removeUnusedCookies();
		jQuery("#cmContentArea").show();
		
		if (window.initBlb && typeof window.initBlb == "function") {
			window.initBlb();
		}

		this.registerEvents();
	};
}

var CookyLaw = (function() {
	// private interface
	var config = {
		// name des clCookies, Konvention
		// host_teil_der_seite_cookies (Beispiel www.bosch-professional.com -> www_bosch-professional_com_cookies )
		clName : "",
		clNameSuffix : "cookies",
		deleteDate : "",
		expireDate : "",
		clLifeTime : "M:5",
		configUrl : "http://dev.bosch.fs.kittelberger.net/master/de/technical-pages/cookielaw.json",
		cookyCategories : {},
		headless : false
	};
	loadingStatus = 0;
	initialized = false;
	toid = -1;
	period = -1;
	var cooky = {};
	var cookyNoti = {};
	var cookyInfo = {};

	/**
	 * ermittelt name des Cl-Cookies
	 * 
	 */
	function determineClCookyName() {
		var url = document.URL;
		var path = url.substring(url.indexOf('://', 0) + 3, url.length);
		var domain = path.substring(0, path.indexOf('/')).replace(/[\.\:]/g,
				'_');
		return domain + "_" + config.clNameSuffix;
	}
	function createDeleteDate() {
		var delDate = new Date();
		delDate.setTime(Date.UTC(1970, 0, 1, 00, 00, 00));
		return delDate;
	}
	function createExpireDate() {
		var expireDate = new Date();
		var tmp = config.clLifeTime.split(":");
		var part = tmp[0].toLowerCase();
		var timeValue = parseInt(tmp[1]);
		switch (part) {
		case "d":
			expireDate.setMilliseconds(expireDate.getMilliseconds()
					+ (timeValue * 86400000));
			break;
		case "m":
			var curMonth = expireDate.getMonth();
			var curDay = expireDate.getDate();
			var curYear = expireDate.getFullYear();
			for (var i = 1; i <= timeValue; i++) {
				if (curMonth + 1 == 12) {
					curYear++;
					curMonth = 0;
				} else {
					curMonth++;
				}
			}
			if (curMonth == 1) {
				// m�glicherweise sind zuviel tage vorhanden
				// februar-> m�glicherweise schaltjahr
				var febDays = 28;
				if (((curYear % 4 === 0) && (curYear % 100 !== 0))
						|| (curYear % 400 === 0)) {
					febDays = 29;
				}
				var difDays = curDay - febDays;
				if (difDays > 0) {
					curMonth++;
					curDay = difDays;
				}
			}
			expireDate.setFullYear(curYear, curMonth, curDay);
			break;
		case "y":
			var curMonth = expireDate.getMonth();
			var curDay = expireDate.getDate();
			var curYear = expireDate.getFullYear() + timeValue;
			if (curMonth == 1) {
				// m�glicherweise sind zuviel tage vorhanden
				// februar-> m�glicherweise schaltjahr
				var febDays = 28;
				if (((curYear % 4 === 0) && (curYear % 100 !== 0))
						|| (curYear % 400 === 0)) {
					febDays = 29;
				}
				var difDays = curDay - febDays;
				if (difDays > 0) {
					curMonth++;
					curDay = difDays;
				}
			}
			expireDate.setFullYear(curYear, curMonth, curDay);
			break;
		default:
			break;
		}
		return expireDate;
	}

	function _log(argument) {
		if(typeof console !== "undefined" && console) {
			console.log(argument);
		}
	}

	/**
	 * l�dt konfiguration
	 */
	function loadConfiguration() {
		var strat = new DefaultConfigUrlResolverStrategy("");
		var configUrl = strat.resolveConfigUrl();
		if(typeof console !== "undefined" && console){
			console.log( "loadConfiguration: " + configUrl);
		}
		loadingStatus = 1;
		if(configUrl && configUrl.length > 0){
			jQuery.ajax({
				dataType : "jsonp",
				url : configUrl,
				jsonpCallback: 'jsonpCallback',
				contentType : "application/json; charset=UTF-8",
				success : function(data, status, xhr) {
					loadingStatus = 3;
					initialized = true;
					jQuery.extend(config, data);
				},
				error : function(xhr, status, error) {
					loadingStatus = 2;
					initialized = false;
					if(typeof console !== "undefined" && console){
						console.log(error);
					}
				},
				complete : function(xhr, status) {
					if(status){				
						var lstatus = status.toLowerCase();
						_log(lstatus);
					};
				}
			});
		}
	}

	/**
	 * pr�ft ob konfiguration initialisiert ist
	 */
	function checkInternalRun() {
		_log("checkInternalRun");
		if ((loadingStatus == 3 && initialized)
				|| (loadingStatus == 2 && !initialized)) {
			clearInterval(period);
			clearTimeout(toid);
			runInternal();
		}
	}

	/**
	 * pr�fen ob CL-Cooky valide ist 
	 */
	function isClCookyValid() {
		var cookyVal = parseInt(cooky.readCooky(config.clName));
		return cookyVal <= getMaxCat();
	}

	function runInternal() {
		_log("runInternal");
		clearInterval(period);
		clearTimeout(toid);
		if(typeof console !== "undefined" && console && config.headless) {
				console.log("runInternal: Running in headlessmode");
		}
		if (isInitialized()) {
			_log("run");
			cookyInfo = new CookyInformation(config);
			cookyNoti = new CookyNotification(config);
			var iconB = new IconBar(config);
			iconB.updateTexts();
			// pr�fen ob cookies eingeschalten sind
			if (cooky.cookiesEnabled()) {
				// cookies eingeschaltet->pr�fen ob cl-cooky vorhanden
				if (cooky.cookyExists(config.clName)) {
					// cooky existiert
					// pr�fen ob cooky kategorie valide ist und ggf anpassen
					if (isClCookyValid()) {
						// cooky ist valide
						// iconbar aktualisieren
						if(!config.headless){
							iconB.update();
						}
						iconB.registerEvents();
					} else {
						// cooky ist nicht valide
						// cl-Hinweis einblenden
						if(!config.headless){
							cookyInfo.render();
						}
						cookyInfo.registerEvents();
					}
				} else {
					// cooky existiert nicht
					// cl-Hinweis einblenden
					if(!config.headless){
						cookyInfo.render();
					}
					cookyInfo.registerEvents();
				}
				// cookies sind grunds�tzlich erlaubt
				// -> Manager einschalten
				var cMan = new CookyManager(config);
				cMan.render();
			} else {
				// cookies abgeschaltet->hinweis rendern
				_log("no cookies");
				if(!config.headless){
					cookyNoti.render();
				}
				cookyNoti.registerEvents();
			}

		} else {
			_log("norun");
		}
	}

	function isInitialized() {
		_log("isInitialized");
		_log(loadingStatus);
		_log(initialized);
		if (loadingStatus == 3 && initialized) {
			return true;
		} else if (loadingStatus == 2 && !initialized) {
			return false;
		}
	}

	var getMaxCat = function() {
		var catNum = -1;
		for ( var k in config.cookyCategories) {
			var keyVal = parseInt(k);
			if (keyVal > catNum) {
				catNum = keyVal;
			}
		}
		return catNum;
	};
	var isConfigValid = function() {
		var retval = true;
		if (!config.clNameSuffix || config.clNameSuffix.length == 0) {
			retval = false;
			if(typeof console !== "undefined" && console) {
				console.log("required clNameSuffix missing in config", config);
			}
		}
		if (!config.clLifeTime || config.clLifeTime.length == 0) {
			retval = false;
			if(typeof console !== "undefined" && console) {
				console.log("required clLifeTime missing in config", config);
			}
		}

		if (!config.cookyCategories
				|| typeof config.cookyCategories != "object") {
			retval = false;
			if(typeof console !== "undefined" && console) {
				console.log("required cookyCategories missing in config",
						config);
			}
		}

		if (!config.cookieNotificationHtml
				|| config.cookieNotificationHtml.length == 0) {
			retval = false;
			if(typeof console !== "undefined" && console) {
				console.log(
						"required cookieNotificationHtml missing in config",
						config);
			}
		}
		if (!config.cookieInformationHtml
				|| config.cookieInformationHtml.length == 0) {
			retval = false;
			if(typeof console !== "undefined" && console) {
				console.log("required cookieInformationHtml missing in config",
						config);
			}
		}

		if (!config.cookies || typeof config.cookies != "object") {
			retval = false;
			if(typeof console !== "undefined" && console) {
				console.log("required cookies missing in config", config);
			}
		}

		if (!config.managerHtml || config.managerHtml.length == 0) {
			retval = false;
			if(typeof console !== "undefined" && console) {
				console.log("required managerHtml missing in config", config);
			}
		}

		return retval;
	};
	return {
		// public interface
		init : function(configParams) {
			cooky = new Cooky();
			jQuery.extend(config, configParams);
			// falls config als parameter, dann config �berschreiben
			config.clName = determineClCookyName();
			config.deleteDate = createDeleteDate();
			config.expireDate = createExpireDate();
			
			if (!isConfigValid()) {
				loadConfiguration();
			} else {
				loadingStatus == 3;
				initialized = true;
			}
			var cooieLawAcceptDeclineHandler = new CooieLawAcceptDeclineHandler();
			
		}, // methode zur cooky bearbeitung sind �ffentlich
		getConfig : function() {
			return config;
		},
		setConfig : function(confParams) {
			jQuery.extend(config, confParams);
		},
		getConfigParam : function(name) {
			return config[name];
		},
		setConfigParam : function(paramName, paramValue) {
			config[paramName] = paramValue;
		},
		run : function() {
			if (isInitialized()) {
				runInternal();
			} else {
				period = setTimeout(runInternal, 1000);
				toid = setInterval(checkInternalRun, 50);
			}

		}

	};
})();


function CookieLawNyroModalFilter(){
	this.is = function(){
		return true;
	};
	this.init = function(obj){
		
	};
	this.afterShowCont = function(obj){
		var cookieLawHtml = jQuery("#cmContentArea:visible");
		var descTables = jQuery(".cmTable:visible");
		if( cookieLawHtml.length > 0 ){
			if(descTables.length == 0){
				jQuery("div.nyroModalCont").width("744px");
			} else {
				jQuery("div.nyroModalCont").width("754px");
			}
		}
	};
}

function CooieLawAcceptDeclineHandler(){
	if(typeof console !== "undefined" && console){
		console.log( "CooieLawAcceptDeclineHandler konstrukor");
	}
	var _self = this;
	jQuery(window).bind("cookieSaved",function(e,data,value){
		_self.track(e,data,value);
	});
	
	var wtArgs = {};
	
	 
	this.track = function(e, data, value){
		var level = -1;
		var paramVal = "not accept cookie";
		if(typeof data !== "undefined" ){
			level = parseInt(data);
		}
		
		if(typeof console !== "undefined" && console){
			console.log( "CooieLawAcceptDeclineHandler e:", e  );
			console.log( "CooieLawAcceptDeclineHandler data:", data  );
			console.log( "CooieLawAcceptDeclineHandler value:", value  );
			
		}
		if(level > -1){
			if(typeof Webtrends !== "undefined" && Webtrends){
				if(typeof console !== "undefined" && console){
					console.log("wt present");
					console.log(typeof Webtrends.multiTrack);
				}
				if(typeof Webtrends.multiTrack === "function"){
					if( level > 0 ){
						paramVal = "accept cookie";
					}
					wtArgs.argsa = ["WT.z_cookie", paramVal];
					
					if(typeof value === "function"){
						wtArgs.callback = value;
					} 
					if(typeof console !== "undefined" && console){
						console.log("wtargs", wtArgs);
					}
					Webtrends.multiTrack(wtArgs);
				}
			} 
				if(typeof value === "function"){
					value();
				}
			
		}
		return true;
	}; 
}
